Documentation
¶
Overview ¶
Package types contains the shared types for emailkit. This package does not import anything from other emailkit packages to avoid circular imports.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CheckLevel ¶
type CheckLevel = string
CheckLevel identifies the validation level.
const ( LevelSyntax CheckLevel = "syntax" LevelDNS CheckLevel = "dns" LevelDomain CheckLevel = "domain" LevelSMTP CheckLevel = "smtp" )
type CheckResult ¶
type CheckResult struct {
Level CheckLevel `json:"level"`
Passed bool `json:"passed"`
Details string `json:"details,omitempty"`
MXHost string `json:"mxHost,omitempty"`
SMTPCode int `json:"smtpCode,omitempty"`
Suggestion string `json:"suggestion,omitempty"`
}
CheckResult is the outcome of a single validation level.
Click to show internal directories.
Click to hide internal directories.