types

package
v0.1.0-rc.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 27, 2026 License: BSD-3-Clause Imports: 0 Imported by: 0

Documentation

Overview

Package types contains the shared types for emailkit. This package does not import anything from other emailkit packages to avoid circular imports.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type CheckLevel

type CheckLevel = string

CheckLevel identifies the validation level.

const (
	LevelSyntax CheckLevel = "syntax"
	LevelDNS    CheckLevel = "dns"
	LevelDomain CheckLevel = "domain"
	LevelSMTP   CheckLevel = "smtp"
)

type CheckResult

type CheckResult struct {
	Level      CheckLevel `json:"level"`
	Passed     bool       `json:"passed"`
	Details    string     `json:"details,omitempty"`
	MXHost     string     `json:"mxHost,omitempty"`
	SMTPCode   int        `json:"smtpCode,omitempty"`
	Suggestion string     `json:"suggestion,omitempty"`
}

CheckResult is the outcome of a single validation level.

Jump to